pywr.recorders.DeficitFrequencyNodeRecorder
===========================================

.. currentmodule:: pywr.recorders

.. autoclass:: DeficitFrequencyNodeRecorder

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~DeficitFrequencyNodeRecorder.after
      ~DeficitFrequencyNodeRecorder.aggregated_value
      ~DeficitFrequencyNodeRecorder.before
      ~DeficitFrequencyNodeRecorder.finish
      ~DeficitFrequencyNodeRecorder.load
      ~DeficitFrequencyNodeRecorder.register
      ~DeficitFrequencyNodeRecorder.reset
      ~DeficitFrequencyNodeRecorder.setup
      ~DeficitFrequencyNodeRecorder.unregister
      ~DeficitFrequencyNodeRecorder.values
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~DeficitFrequencyNodeRecorder.agg_func
      ~DeficitFrequencyNodeRecorder.children
      ~DeficitFrequencyNodeRecorder.comment
      ~DeficitFrequencyNodeRecorder.epsilon
      ~DeficitFrequencyNodeRecorder.ignore_nan
      ~DeficitFrequencyNodeRecorder.is_constraint
      ~DeficitFrequencyNodeRecorder.is_objective
      ~DeficitFrequencyNodeRecorder.model
      ~DeficitFrequencyNodeRecorder.name
      ~DeficitFrequencyNodeRecorder.node
      ~DeficitFrequencyNodeRecorder.parents
   
   